@@ -9,6 +9,14 @@ from pywin.mfc import dialog
 
 
 class ChangeTimeDialog():
+    """
+    Singleton class providing the dialog to change the time
+
+    .. note:: An experiment using the resource parser. The resource file nx_work_log.rc can be opened and modified in
+              Microsoft Visual Studio
+    .. document private classes
+    .. automethod:: __ChangeTimeDialog
+    """
     instance = None
 
     def __new__(cls):
@@ -23,13 +31,23 @@ class ChangeTimeDialog():
         return setattr(self.instance, name)
 
     class __ChangeTimeDialog(dialog.Dialog):
+        """
+        Internal class implementing the change time dialog
+        :public
+        """
+
         def __init__(self):
             self.hwnd = None
             rc_file = os.path.join(os.path.abspath(os.path.dirname(__file__)), 'nx_work_log.rc')
             self.resources = win32rcparser.Parse(rc_file)
             self.minutes = 0
+            self.time_changed_callback = None
 
         def get_time(self):
+            """
+            Get the current logged number of minutes
+            :return: Number of minutes
+            """
             if self.hwnd is not None:
                 minutes = 60 * int(win32gui.GetWindowText(win32gui.GetDlgItem(self.hwnd, self.resources.ids['IDC_HOURS'])))
                 minutes += int(win32gui.GetWindowText(win32gui.GetDlgItem(self.hwnd, self.resources.ids['IDC_MINUTES'])))
@@ -38,13 +56,30 @@ class ChangeTimeDialog():
             return self.minutes
 
         def set_time(self, minutes):
+            """
+            Set the current logged number of minutes
+            :param minutes: Number of minutes
+            """
             self.minutes = minutes
 
             if self.hwnd is not None:
                 win32gui.SetWindowText(win32gui.GetDlgItem(self.hwnd, self.resources.ids['IDC_HOURS']), str(int(self.minutes / 60)))
                 win32gui.SetWindowText(win32gui.GetDlgItem(self.hwnd, self.resources.ids['IDC_MINUTES']), str(self.minutes % 60))
 
+            if self.time_changed_callback is not None:
+                self.time_changed_callback(minutes)
+
+        def set_time_changed_callback(self, time_changed_callback):
+            """
+            Set the callback function for time changes
+            :param time_changed_callback: Callback function
+            """
+            self.time_changed_callback = time_changed_callback
+
         def show_window(self):
+            """
+            Show the change time dialog window
+            """
             if self.hwnd is None:
                 self.__create_window()
             else:
